@@ -33,11 +33,11 @@ DBUS_BEGIN_DECLS
 
 /* D-Bus no longer supports platforms with no 64-bit integer type. */
 #define DBUS_HAVE_INT64 1
-_DBUS_GNUC_EXTENSION typedef long dbus_int64_t;
-_DBUS_GNUC_EXTENSION typedef unsigned long dbus_uint64_t;
+_DBUS_GNUC_EXTENSION typedef long long dbus_int64_t;
+_DBUS_GNUC_EXTENSION typedef unsigned long long dbus_uint64_t;
 
-#define DBUS_INT64_CONSTANT(val)  (_DBUS_GNUC_EXTENSION (val##L))
-#define DBUS_UINT64_CONSTANT(val) (_DBUS_GNUC_EXTENSION (val##UL))
+#define DBUS_INT64_CONSTANT(val)  (_DBUS_GNUC_EXTENSION (val##LL))
+#define DBUS_UINT64_CONSTANT(val) (_DBUS_GNUC_EXTENSION (val##ULL))
 
 typedef int dbus_int32_t;
 typedef unsigned int dbus_uint32_t;
@@ -49,12 +49,12 @@ typedef unsigned short dbus_uint16_t;
  * creating an additional generated header just for this
  */
 #define DBUS_MAJOR_VERSION 1
-#define DBUS_MINOR_VERSION 10
-#define DBUS_MICRO_VERSION 22
+#define DBUS_MINOR_VERSION 12
+#define DBUS_MICRO_VERSION 10
 
-#define DBUS_VERSION_STRING "1.10.22"
+#define DBUS_VERSION_STRING "1.12.10"
 
-#define DBUS_VERSION ((1 << 16) | (10 << 8) | (22)) 
+#define DBUS_VERSION ((1 << 16) | (12 << 8) | (10)) 
 
 DBUS_END_DECLS
 
